@@ -26,6 +26,7 @@ const char ZOOM_RATIO_KEY[] = "zoom_ratio";
 const char SCALE_MODE_KEY[] = "scale_mode";
 const char CROP_MODE_KEY[] = "crop_mode";
 const char CROP_ZOOM_RATIO_KEY[] = "crop_zoom_ratio";
+const char RELOAD_FROM_DISK_KEY[] = "period_reload_from_disk";
 const char PROMPT_TO_SAVE_CHANGES_KEY[] = "prompt_to_save_changes";
 const char RECENT_FILES_LIST_KEY[] = "recent_files_list";
 const char MAX_RECENT_FILES_NUMBER_KEY[] = "max_recent_files_number";
@@ -40,6 +41,8 @@ const char USE_SPACES_AS_TAB_KEY[] = "use_spaces_as_tab";
 const char SPACES_IN_TAB_KEY[] = "spaces_in_tab";
 const char REMEMBER_LAST_PREVIEW_FRAME_KEY[] = "remember_last_preview_frame";
 const char LAST_PREVIEW_FRAME_KEY[] = "last_preview_frame";
+const char LAST_PREVIEW_TIMESTAMP_KEY[] = "last_preview_timestamp";
+const char SYNC_OUTPUT_MODE_KEY[] = "sync_output_node_mode";
 const char NEW_SCRIPT_TEMPLATE_KEY[] = "new_script_template";
 const char HIGHLIGHT_SELECTION_MATCHES_KEY[] = "highlight_selection_matches";
 const char HIGHLIGHT_SELECTION_MATCHES_MIN_LENGTH_KEY[] =
@@ -48,7 +51,7 @@ const char TIMELINE_PANEL_VISIBLE_KEY[] = "timeline_panel_visible";
 const char ALWAYS_KEEP_CURRENT_FRAME_KEY[] = "always_keep_current_frame";
 const char LAST_SNAPSHOT_EXTENSION_KEY[] = "last_snapshot_extension";
 const char PNG_COMPRESSION_LEVEL_KEY[] = "png_compression_level";
-const char RELOAD_BEFORE_EXECUTION_KEY[] = "reload_before_execution";
+const char DEBUG_MESSAGES_KEY[] = "show_debug_messages";
 const char DARK_MODE_KEY[] = "dark_mode";
 const char SILENT_SNAPSHOT_KEY[] = "silent_snapshot";
 const char SNAPSHOT_TEMPLATE_KEY[] = "snapshot_template";
@@ -228,6 +231,8 @@ void SettingsManager::initializeStandardActions()
 			QIcon(":exit.png"), QKeySequence()},
 		{ACTION_ID_SET_TRUSTED_CLIENTS_ADDRESSES,
 			tr("Set trusted clients addresses"), QIcon(), QKeySequence()},
+		{ACTION_ID_JUMP_TO_FRAME, tr("Jump to frame..."),
+			QIcon(), QKeySequence(Qt::Key_J)},
 		{ACTION_ID_TOGGLE_FRAME_PROPS, tr("Toggle frame properties panel"),
 			QIcon(), QKeySequence(Qt::Key_P)},
 		{ACTION_ID_SET_OUTPUT_INDEX_0, tr("Switch to output index 0"),
@@ -270,6 +275,10 @@ void SettingsManager::initializeStandardActions()
 			QIcon(), QKeySequence()},
 		{ACTION_ID_SET_OUTPUT_INDEX_19, tr("Switch to output index 19"),
 			QIcon(), QKeySequence()},
+		{ACTION_ID_PREVIOUS_OUTPUT_INDEX, "Switch to previous output index",
+			QIcon(), QKeySequence()},
+		{ACTION_ID_NEXT_OUTPUT_INDEX, "Switch to next output index",
+			QIcon(), QKeySequence()},
 	};
 }
 
@@ -752,6 +761,16 @@ bool SettingsManager::setMaxRecentFilesNumber(
 	return setValue(MAX_RECENT_FILES_NUMBER_KEY, a_maxRecentFilesNumber);
 }
 
+bool SettingsManager::getReloadScriptFromDisk() const
+{
+	return value(RELOAD_FROM_DISK_KEY, DEFAULT_RELOAD_FROM_DISK).toBool();
+}
+
+bool SettingsManager::setReloadScriptFromDisk(bool a_reload)
+{
+	return setValue(RELOAD_FROM_DISK_KEY, a_reload);
+}
+
 //==============================================================================
 
 int SettingsManager::getCharactersTypedToStartCompletion() const
@@ -904,6 +923,33 @@ bool SettingsManager::setLastPreviewFrame(int a_frameNumber, bool a_inPreviewer)
 	return setValue(LAST_PREVIEW_FRAME_KEY, a_frameNumber);
 }
 
+qlonglong SettingsManager::getLastPreviewTimestamp(bool a_inPreviewer) const
+{
+	if(a_inPreviewer)
+		return valueInGroup(PREVIEWER_GROUP, LAST_PREVIEW_TIMESTAMP_KEY,
+			DEFAULT_LAST_PREVIEW_TIMESTAMP).toLongLong();
+	return value(LAST_PREVIEW_TIMESTAMP_KEY,
+			DEFAULT_LAST_PREVIEW_TIMESTAMP).toLongLong();
+}
+
+bool SettingsManager::setLastPreviewTimestamp(qlonglong a_ms, bool a_inPreviewer)
+{
+	if(a_inPreviewer)
+		return setValueInGroup(PREVIEWER_GROUP, LAST_PREVIEW_TIMESTAMP_KEY, a_ms);
+	return setValue(LAST_PREVIEW_TIMESTAMP_KEY, a_ms);
+}
+
+SyncOutputNodesMode SettingsManager::getSyncOutputMode() const
+{
+	return (SyncOutputNodesMode)value(SYNC_OUTPUT_MODE_KEY,
+		(int)DEFAULT_SYNC_OUTPUT_MODE).toInt();
+}
+
+bool SettingsManager::setSyncOutputMode(SyncOutputNodesMode a_mode)
+{
+	return setValue(SYNC_OUTPUT_MODE_KEY, (int)a_mode);
+}
+
 //==============================================================================
 
 QString SettingsManager::getDefaultNewScriptTemplate()
@@ -1197,15 +1243,14 @@ bool SettingsManager::setPNGSnapshotCompressionLevel(int a_level)
 	return setValue(PNG_COMPRESSION_LEVEL_KEY, a_level);
 }
 
-bool SettingsManager::getReloadBeforeExecution() const
+bool SettingsManager::getShowDebugMessages() const
 {
-	return value(RELOAD_BEFORE_EXECUTION_KEY,
-		DEFAULT_RELOAD_BEFORE_EXECUTION).toBool();
+    return value(DEBUG_MESSAGES_KEY, DEFAULT_DEBUG_MESSAGES).toBool();
 }
 
-bool SettingsManager::setReloadBeforeExecution(bool a_reload)
+bool SettingsManager::setShowDebugMessages(bool a_debug)
 {
-	return setValue(RELOAD_BEFORE_EXECUTION_KEY, a_reload);
+    return setValue(DEBUG_MESSAGES_KEY, a_debug);
 }
 
 bool SettingsManager::getDarkMode() const
