@@ -16,13 +16,13 @@ const char COMMON_GROUP[] = "common";
 
 const char VAPOURSYNTH_LIBRARY_PATHS_KEY[] = "vapoursynth_library_paths";
 const char PREFER_VS_LIBRARIES_FROM_LIST_KEY[] = "prefer_vs_libs_from_list";
-const char VAPOURSYNTH_PLUGINS_PATHS_KEY[] = "vapoursynth_plugins_paths";
 const char CHROMA_RESAMPLING_FILTER_KEY[] = "chroma_resampling_filter";
 const char YUV_MATRIX_COEFFICIENTS_KEY[] = "yuv_matrix_coefficients";
 const char CHROMA_PLACEMENT_KEY[] = "chroma_placement";
 const char BICUBIC_FILTER_PARAMETER_B_KEY[] = "bicubic_filter_parameter_b";
 const char BICUBIC_FILTER_PARAMETER_C_KEY[] = "bicubic_filter_parameter_c";
 const char LANCZOS_FILTER_TAPS_KEY[] = "lanczos_filter_taps";
+const char DITHER_TYPE_KEY[] = "dither_type";
 const char RECENT_JOB_SERVERS_KEY[] = "recent_job_servers";
 const char TRUSTED_CLIENTS_ADDRESSES_KEY[] = "trusted_clients_addresses";
 
@@ -230,21 +230,6 @@ bool SettingsManagerCore::setVapourSynthLibraryPaths(
 
 //==============================================================================
 
-QStringList SettingsManagerCore::getVapourSynthPluginsPaths() const
-{
-	QStringList paths = value(VAPOURSYNTH_PLUGINS_PATHS_KEY).toStringList();
-	paths.removeDuplicates();
-	return paths;
-}
-
-bool SettingsManagerCore::setVapourSynthPluginsPaths(
-	const QStringList & a_pathsList)
-{
-	return setValue(VAPOURSYNTH_PLUGINS_PATHS_KEY, a_pathsList);
-}
-
-//==============================================================================
-
 ResamplingFilter SettingsManagerCore::getChromaResamplingFilter() const
 {
 	return (ResamplingFilter)value(CHROMA_RESAMPLING_FILTER_KEY,
@@ -321,6 +306,17 @@ bool SettingsManagerCore::setLanczosFilterTaps(int a_taps)
 	return setValue(LANCZOS_FILTER_TAPS_KEY, a_taps);
 }
 
+DitherType SettingsManagerCore::getDitherType() const
+{
+    return (DitherType)value(DITHER_TYPE_KEY,
+		(int)DEFAULT_DITHER_TYPE).toInt();
+}
+
+bool SettingsManagerCore::setDitherType(DitherType a_dither)
+{
+    return setValue(DITHER_TYPE_KEY, (int)a_dither);
+}
+
 //==============================================================================
 
 std::vector<EncodingPreset> SettingsManagerCore::getAllEncodingPresets() const
