@@ -53,6 +53,7 @@ VapourSynthScriptProcessor::VapourSynthScriptProcessor(
 	, m_initialized(false)
 	, m_cpVSAPI(nullptr)
 	, m_pVSScript(nullptr)
+	, m_pCore(nullptr)
 	, m_nodeInfo()
 	, m_finalizing(false)
 {
@@ -85,8 +86,11 @@ bool VapourSynthScriptProcessor::initialize(const QString& a_script,
 		return false;
 	}
 
-	if(!m_pVSScript)
-		m_pVSScript = m_pVSScriptLibrary->createScript();
+	if(!m_pVSScript || !m_pCore)
+	{
+		m_pCore = m_pVSScriptLibrary->createCore();
+		m_pVSScript = m_pVSScriptLibrary->createScript(m_pCore);
+	}
 	if(!m_pVSScript)
 	{
 		m_error = tr("Failed to create VSScript handle!");
@@ -95,6 +99,15 @@ bool VapourSynthScriptProcessor::initialize(const QString& a_script,
 		return false;
 	}
 
+	m_cpVSAPI = m_pVSScriptLibrary->getVSAPI();
+	if(!m_cpVSAPI)
+	{
+		finalize();
+		return false;
+	}
+
+	m_cpVSAPI->getCoreInfo(m_pCore, &m_cpCoreInfo);
+
 	int opresult = m_pVSScriptLibrary->evaluateScript(m_pVSScript,
 		a_script.toUtf8().constData(), a_scriptName.toUtf8().constData());
 
@@ -112,16 +125,6 @@ bool VapourSynthScriptProcessor::initialize(const QString& a_script,
 		return false;
 	}
 
-	m_cpVSAPI = m_pVSScriptLibrary->getVSAPI();
-	if(!m_cpVSAPI)
-	{
-		finalize();
-		return false;
-	}
-
-	VSCore * pCore = m_pVSScriptLibrary->getCore(m_pVSScript);
-	m_cpVSAPI->getCoreInfo(pCore, &m_cpCoreInfo);
-
 	VSNode * pOutputNode = m_pVSScriptLibrary->getOutput(
 		m_pVSScript, a_outputIndex);
 	if(!pOutputNode)
@@ -135,12 +138,20 @@ bool VapourSynthScriptProcessor::initialize(const QString& a_script,
 
 	m_nodeInfo = VSNodeInfo(pOutputNode, m_cpVSAPI);
 
+#ifdef Q_OS_WIN // AUDIO
+	if(a_reason == ProcessReason::Encode && m_nodeInfo.isAudio())
+#else
 	if((a_reason == ProcessReason::Preview
 		|| a_reason == ProcessReason::Encode) && m_nodeInfo.isAudio())
+#endif
 	{
 		m_cpVSAPI->freeNode(pOutputNode);
 		m_error = tr("Output node #%1 is audio. "
+#ifdef Q_OS_WIN // AUDIO
+			"Encoding audio are not supported.")
+#else
 			"Previewing and encoding audio are not supported.")
+#endif
 			.arg(a_outputIndex);
 		emit signalWriteLogMessage(
 			a_outputIndex == 0 ? mtCritical : mtWarning, m_error);
@@ -228,6 +239,14 @@ QString VapourSynthScriptProcessor::error() const
 // END OF QString VapourSynthScriptProcessor::error() const
 //==============================================================================
 
+std::vector<int> VapourSynthScriptProcessor::getOutputIndices() const
+{
+	if(!isInitialized() || !m_pVSScript)
+    	return std::vector<int>();
+
+	return m_pVSScriptLibrary->getOutputIndices(m_pVSScript);
+}
+
 VSNodeInfo VapourSynthScriptProcessor::nodeInfo(int a_outputIndex)
 {
 	if(!m_initialized)
@@ -266,7 +285,7 @@ bool VapourSynthScriptProcessor::requestFrameAsync(int a_frameNumber,
 	if(a_frameNumber < 0)
 	{
 		m_error = tr("Requested frame number %1 is negative.")
-			.arg(a_outputIndex);
+			.arg(a_frameNumber);
 		emit signalWriteLogMessage(mtCritical, m_error);
 		return false;
 	}
@@ -394,6 +413,8 @@ void VapourSynthScriptProcessor::slotResetSettings()
 
 	m_chromaPlacement = m_pSettingsManager->getChromaPlacement();
 
+	m_ditherType = m_pSettingsManager->getDitherType();
+
 	for(std::pair<const int, NodePair> & mapItem : m_nodePairForOutputIndex)
 	{
 		NodePair & nodePair = mapItem.second;
@@ -558,8 +579,14 @@ void VapourSynthScriptProcessor::sendFrameQueueChangeSignal()
 {
 	size_t inQueue = m_frameTicketsQueue.size();
 	size_t inProcess = m_frameTicketsInProcess.size();
+
+	m_cpVSAPI->getCoreInfo(m_pCore, &m_cpCoreInfo);
+
 	size_t maxThreads = m_cpCoreInfo.numThreads;
-	emit signalFrameQueueStateChanged(inQueue, inProcess, maxThreads);
+	double usedCacheRatio = (double)m_cpCoreInfo.usedFramebufferSize
+		/ (double)m_cpCoreInfo.maxFramebufferSize;
+	emit signalFrameQueueStateChanged(inQueue, inProcess, maxThreads,
+		usedCacheRatio);
 }
 
 // END OF void VapourSynthScriptProcessor::sendFrameQueueChangeSignal()
@@ -582,9 +609,13 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 	int outputMediaType = m_cpVSAPI->getNodeType(a_nodePair.pOutputNode);
 	if(outputMediaType == mtAudio)
 	{
-		m_error = tr("Audio playback is not supported.");
+#ifdef Q_OS_WIN // AUDIO
+		return recreateAudioPreviewNode(a_nodePair);
+#else
+		m_error = tr("Audio playback is supported on Windows only.");
 		emit signalWriteLogMessage(mtCritical, m_error);
 		return false;
+#endif
 	}
 
 	const VSVideoInfo * cpVideoInfo =
@@ -596,9 +627,8 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 	bool to_10_bit = (QColormap::instance().depth() == 30);
 
 	VSMap * pResultMap = nullptr;
-	VSCore * pCore = m_pVSScriptLibrary->getCore(m_pVSScript);
 
-	if(vsh::isSameVideoPresetFormat(pfRGB24, cpFormat, pCore, m_cpVSAPI))
+	if(vsh::isSameVideoPresetFormat(pfRGB24, cpFormat, m_pCore, m_cpVSAPI))
 	{
 		to_10_bit = false;
 		pResultMap = m_cpVSAPI->createMap();
@@ -606,7 +636,7 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 			maReplace);
 	}
 	else if(to_10_bit &&
-		vsh::isSameVideoPresetFormat(pfRGB30, cpFormat, pCore, m_cpVSAPI))
+		vsh::isSameVideoPresetFormat(pfRGB30, cpFormat, m_pCore, m_cpVSAPI))
 	{
 		pResultMap = m_cpVSAPI->createMap();
 		m_cpVSAPI->mapSetNode(pResultMap, "clip", a_nodePair.pOutputNode,
@@ -618,11 +648,16 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 		bool isYUV = cpFormat->colorFamily == cfYUV;
 
 		VSPlugin * pResizePlugin = m_cpVSAPI->getPluginByID(
-			"com.vapoursynth.resize", pCore);
+			"com.vapoursynth.resize", m_pCore);
 		const char * resizeName = "Point";
 
 		VSMap * pArgumentMap = m_cpVSAPI->createMap();
 
+		VSCoreInfo coreInfo;
+		m_cpVSAPI->getCoreInfo(m_pCore, &coreInfo);
+		if(coreInfo.core < 58)
+			m_cpVSAPI->mapSetInt(pArgumentMap, "prefer_props", 1, maReplace);
+
 		// Set matrix and chromaloc
 
 		int64_t matrixIn;
@@ -640,26 +675,12 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 		case YuvMatrixCoefficients::m2020_NCL:
 			matrixIn = VSC_MATRIX_BT2020_NCL;
 			break;
-		case YuvMatrixCoefficients::m2020_CL:
-			matrixIn = VSC_MATRIX_BT2020_CL;
-			break;
 		default:
 			Q_ASSERT(false);
 		}
 
 		m_cpVSAPI->mapSetInt(pArgumentMap, "matrix_in", matrixIn, maReplace);
 
-		if(m_yuvMatrix == YuvMatrixCoefficients::m2020_CL)
-		{
-			int64_t transferIn = VSC_TRANSFER_BT709;
-			int64_t transferOut = VSC_TRANSFER_BT2020_10;
-
-			m_cpVSAPI->mapSetInt(pArgumentMap, "transfer_in",
-				transferIn, maReplace);
-			m_cpVSAPI->mapSetInt(pArgumentMap, "transfer",
-				transferOut, maReplace);
-		}
-
 		int64_t chromaLoc;
 		switch(m_chromaPlacement)
 		{
@@ -677,20 +698,38 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 		}
 		m_cpVSAPI->mapSetInt(pArgumentMap, "chromaloc_in", chromaLoc, maReplace);
 
+		QString ditherType;
+		switch (m_ditherType)
+		{
+		case DitherType::NONE:
+			ditherType = "none";
+			break;
+		case DitherType::ORDERED:
+			ditherType = "ordered";
+			break;
+		case DitherType::RANDOM:
+			ditherType = "random";
+			break;
+		case DitherType::ERROR_DIFFUSION:
+			ditherType = "error_diffusion";
+			break;
+		default:
+			Q_ASSERT(false);
+		}
+		m_cpVSAPI->mapSetData(pArgumentMap, "dither_type",
+			ditherType.toStdString().c_str(), ditherType.size(),
+			dtUtf8, maReplace);
+
 		VSMap *pTempMap = m_cpVSAPI->createMap();
 		m_cpVSAPI->copyMap(pArgumentMap, pTempMap);
 		m_cpVSAPI->mapSetNode(pTempMap, "clip",
 			a_nodePair.pOutputNode, maReplace);
-		setMatrixFilter(pTempMap, pArgumentMap, pCore, m_cpVSAPI);
+		setMatrixFilter(pTempMap, pArgumentMap, m_pCore, m_cpVSAPI);
 		m_cpVSAPI->clearMap(pTempMap);
 
 		m_cpVSAPI->mapSetInt(pArgumentMap, "format", (to_10_bit ?
 			pfRGB30 : pfRGB24), maReplace);
 
-		const char * dither_type = "error_diffusion";
-		m_cpVSAPI->mapSetData(pArgumentMap, "dither_type",
-				dither_type, (int)strlen(dither_type), dtUtf8, maReplace);
-
 		if(isYUV || isVF)
 		{
 			switch(m_chromaResamplingFilter)
@@ -743,20 +782,15 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 		return false;
 	}
 
-	VSMap * pPackedMap = m_cpVSAPI->createMap();
-
-	to_10_bit ?
-		packCreateRGB30(pResultMap, pPackedMap, pCore, m_cpVSAPI):
-		packCreateRGB24(pResultMap, pPackedMap, pCore, m_cpVSAPI);
-
+	VSNode * pRGBNode = m_cpVSAPI->mapGetNode(pResultMap, "clip", 0, nullptr);
 	m_cpVSAPI->freeMap(pResultMap);
 
-	VSNode * pPreviewNode = m_cpVSAPI->mapGetNode(pPackedMap, "clip", 0, nullptr);
+	VSNode * pPreviewNode = packRGBFilter(pRGBNode, a_nodePair.pOutputNode,
+		to_10_bit, m_pCore, m_cpVSAPI);
+
 	Q_ASSERT(pPreviewNode);
 	a_nodePair.pPreviewNode = pPreviewNode;
 
-	m_cpVSAPI->freeMap(pPackedMap);
-
 	return true;
 }
 
@@ -764,6 +798,37 @@ bool VapourSynthScriptProcessor::recreatePreviewNode(NodePair & a_nodePair)
 //		NodePair & a_nodePair)
 //==============================================================================
 
+bool VapourSynthScriptProcessor::recreateAudioPreviewNode(NodePair &a_nodePair)
+{
+	Q_ASSERT(m_pCore);
+
+	const VSAudioInfo * cpAudioInfo =
+		m_cpVSAPI->getAudioInfo(a_nodePair.pOutputNode);
+
+	VSMap * map = m_cpVSAPI->createMap();
+	VSPlugin *stdPlugin = m_cpVSAPI->getPluginByID(VSH_STD_PLUGIN_ID, m_pCore);
+	m_cpVSAPI->mapSetInt(map, "length", cpAudioInfo->numFrames, maReplace);
+	VSMap * blankMap = m_cpVSAPI->invoke(stdPlugin, "BlankClip", map);
+	m_cpVSAPI->clearMap(map);
+
+	QString props = vsedit::nodeInfoString(
+		nodeInfo(a_nodePair.outputIndex), m_cpVSAPI);
+	QString text = QString("Audio node #%1\n\n").arg(a_nodePair.outputIndex)
+		+ props.replace("| ", "\n");
+    m_cpVSAPI->mapSetData(blankMap, "text", text.toStdString().c_str(),
+		text.size(), dtUtf8, maReplace);
+	VSPlugin * textPlugin = m_cpVSAPI->getPluginByID(VSH_TEXT_PLUGIN_ID, m_pCore);
+    VSMap * textMap = m_cpVSAPI->invoke(textPlugin, "Text", blankMap);
+	m_cpVSAPI->clearMap(blankMap);
+
+	VSNode * textClip = m_cpVSAPI->mapGetNode(textMap, "clip", 0, nullptr);
+	m_cpVSAPI->clearMap(textMap);
+
+	a_nodePair.pPreviewNode = packRGBFilter(textClip, a_nodePair.pOutputNode,
+		false, m_pCore, m_cpVSAPI);
+    return true;
+}
+
 void VapourSynthScriptProcessor::freeFrameTicket(FrameTicket & a_ticket)
 {
 	Q_ASSERT(m_cpVSAPI);
@@ -805,6 +870,8 @@ NodePair & VapourSynthScriptProcessor::getNodePair(int a_outputIndex,
 {
 	NodePair & nodePair = m_nodePairForOutputIndex[a_outputIndex];
 
+	nodePair.outputIndex = a_outputIndex;
+
 	if(!nodePair.pOutputNode)
 	{
 		Q_ASSERT(!nodePair.pPreviewNode);
@@ -851,7 +918,7 @@ QString VapourSynthScriptProcessor::framePropsString(
 	QString propsString;
 	QStringList propsStringList;
 
-	std::map<char, QString> propTypeToString =
+	static std::map<VSPropertyType, QString> propTypeToString =
 	{
 		{ptUnset, "<unset>"},
 		{ptInt, "int"},
@@ -864,6 +931,99 @@ QString VapourSynthScriptProcessor::framePropsString(
 		{ptAudioFrame, "aframe"}
 	};
 
+	static std::map<int64_t, QString> _ChromaLocationToString = 
+	{
+		{VSC_CHROMA_LEFT, "left"},
+		{VSC_CHROMA_CENTER, "center"},
+		{VSC_CHROMA_TOP_LEFT, "top left"},
+		{VSC_CHROMA_BOTTOM_LEFT, "bottom left"},
+		{VSC_CHROMA_BOTTOM, "bottom"},
+	};
+
+	static std::map<int64_t, QString> _ColorRangeToString = 
+	{
+		{VSC_RANGE_FULL, "full"},
+		{VSC_RANGE_LIMITED, "limited"},
+	};
+
+	static std::map<int64_t, QString> _PrimariesToString = 
+	{
+		{VSC_PRIMARIES_BT709, "709"},
+		{VSC_PRIMARIES_UNSPECIFIED, "unspec"},
+		{VSC_PRIMARIES_BT470_M, "470m"},
+		{VSC_PRIMARIES_BT470_BG, "470bg"},
+		{VSC_PRIMARIES_ST170_M, "170m"},
+		{VSC_PRIMARIES_ST240_M, "240m"},
+		{VSC_PRIMARIES_FILM, "film"},
+		{VSC_PRIMARIES_BT2020, "2020"},
+		{VSC_PRIMARIES_ST428, "st428"},
+		{VSC_PRIMARIES_ST431_2, "st431-2"},
+		{VSC_PRIMARIES_ST432_1, "st432-1"},
+		{VSC_PRIMARIES_EBU3213_E, "jedec-p22"},
+	};
+
+	static std::map<int64_t, QString> _MatrixToString =
+	{
+		{VSC_MATRIX_RGB, "rgb"},
+		{VSC_MATRIX_BT709, "709"},
+		{VSC_MATRIX_UNSPECIFIED, "unspec"},
+		{VSC_MATRIX_FCC, "fcc"},
+		{VSC_MATRIX_BT470_BG, "470bg"},
+		{VSC_MATRIX_ST170_M, "170m"},
+		{VSC_MATRIX_ST240_M, "240m"},
+		{VSC_MATRIX_YCGCO, "ycgco"},
+		{VSC_MATRIX_BT2020_NCL, "2020ncl"},
+		{VSC_MATRIX_BT2020_CL, "2020cl"},
+		{VSC_MATRIX_CHROMATICITY_DERIVED_NCL, "chromancl"},
+		{VSC_MATRIX_CHROMATICITY_DERIVED_CL, "chromacl"},
+		{VSC_MATRIX_ICTCP, "ictcp"},
+	};
+
+	static std::map<int64_t, QString> _TransferToString =
+	{
+		{VSC_TRANSFER_BT709, "709"},
+		{VSC_TRANSFER_UNSPECIFIED, "unspec"},
+		{VSC_TRANSFER_BT470_M, "470m"},
+		{VSC_TRANSFER_BT470_BG, "470bg"},
+		{VSC_TRANSFER_BT601, "601"},
+		{VSC_TRANSFER_ST240_M, "240m"},
+		{VSC_TRANSFER_LINEAR, "linear"},
+		{VSC_TRANSFER_LOG_100, "log100"},
+		{VSC_TRANSFER_LOG_316, "log316"},
+		{VSC_TRANSFER_IEC_61966_2_4, "xvycc"},
+		{VSC_TRANSFER_IEC_61966_2_1, "srgb"},
+		{VSC_TRANSFER_BT2020_10, "2020_10"},
+		{VSC_TRANSFER_BT2020_12, "2020_12"},
+		{VSC_TRANSFER_ST2084, "st2084"},
+		//{VSC_TRANSFER_ST428, "st428"},
+		{17, "st428"},
+		{VSC_TRANSFER_ARIB_B67, "std-b67"},
+	};
+
+	static std::map<int64_t, QString> _FieldBasedToString =
+	{
+		{VSC_FIELD_PROGRESSIVE, "progressive"},
+		{VSC_FIELD_BOTTOM, "bottom field first"},
+		{VSC_FIELD_TOP, "top field first"},
+	};
+
+	static std::map<int64_t, QString> _FieldToString =
+	{
+		{0, "from bottom field"},
+		{1, "from top field"},
+	};
+
+	static std::map<QString, std::map<int64_t, QString>> reservedPropToMap =
+	{
+		{"_ChromaLocation", _ChromaLocationToString},
+		{"_ColorRange", _ColorRangeToString},
+		{"_Primaries", _PrimariesToString},
+		{"_Matrix", _MatrixToString},
+		{"_Transfer", _TransferToString},
+		{"_FieldBased", _FieldBasedToString},
+		{"_Field", _FieldToString},
+	};
+
 	const VSMap * cpProps = m_cpVSAPI->getFramePropertiesRO(a_cpFrame);
 
 	int propsNumber = m_cpVSAPI->mapNumKeys(cpProps);
@@ -873,7 +1033,7 @@ QString VapourSynthScriptProcessor::framePropsString(
 		if(!propKey)
 			continue;
 		QString currentPropString = QString("%1 : ").arg(propKey);
-		int propType = m_cpVSAPI->mapGetType(cpProps, propKey);
+		auto propType = (VSPropertyType)m_cpVSAPI->mapGetType(cpProps, propKey);
 		currentPropString += propTypeToString[propType];
 		int elementsNumber = m_cpVSAPI->mapNumElements(cpProps, propKey);
 		if(elementsNumber > 1)
@@ -890,7 +1050,58 @@ QString VapourSynthScriptProcessor::framePropsString(
 			currentPropString += ": <unset>";
 			break;
 		case ptInt:
+		{
+			currentPropString += " : ";
+			QStringList elementStringList;
+			for(int j = 0; j < elementsNumber; ++j)
+			{
+				QString elementString;
+				int error;
+				int64_t element = m_cpVSAPI->mapGetInt(cpProps,
+					propKey, j, &error);
+				if(error)
+					elementString = "<error>";
+				else
+				{
+					auto it = reservedPropToMap.find(QString(propKey));
+					if(it == reservedPropToMap.end())
+						elementString = QString::number(element);
+					else
+					{
+						auto it2 = it->second.find(element);
+						if(it2 == it->second.end())
+							elementString = QString::number(element);
+						else
+							elementString = QString("%1 (%2)")
+								.arg(element).arg(it2->second);
+					}
+				}
+
+				elementStringList += elementString;
+			}
+			currentPropString += elementStringList.join(", ");
+			break;
+		}
 		case ptFloat:
+		{
+			currentPropString += " : ";
+			QStringList elementStringList;
+			for(int j = 0; j < elementsNumber; ++j)
+			{
+				QString elementString;
+				int error;
+				double element = m_cpVSAPI->mapGetFloat(cpProps,
+					propKey, j, &error);
+				if(error)
+					elementString = "<error>";
+				else
+					elementString = QString::number(element);
+
+				elementStringList += elementString;
+			}
+			currentPropString += elementStringList.join(", ");
+			break;
+		}
 		case ptData:
 		{
 			currentPropString += " : ";
@@ -899,65 +1110,44 @@ QString VapourSynthScriptProcessor::framePropsString(
 			{
 				QString elementString;
 				int error;
-				if(propType == ptInt)
+				int hint = m_cpVSAPI->mapGetDataTypeHint(cpProps,
+					propKey, j, &error);
+				if(error)
+					elementString = "<error>";
+				else if(hint == dtUtf8)
 				{
-					int64_t element = m_cpVSAPI->mapGetInt(cpProps,
+					const char * element = m_cpVSAPI->mapGetData(cpProps,
 						propKey, j, &error);
 					if(error)
 						elementString = "<error>";
 					else
-						elementString = QString::number(element);
+						elementString = QString::fromUtf8(element);
 				}
-				else if(propType == ptFloat)
+				else if(hint == dtBinary)
 				{
-					double element = m_cpVSAPI->mapGetFloat(cpProps,
+					int len = m_cpVSAPI->mapGetDataSize(cpProps,
 						propKey, j, &error);
 					if(error)
 						elementString = "<error>";
 					else
-						elementString = QString::number(element);
+						elementString = QString("<binary with %1 bytes>")
+							.arg(len);
 				}
-				else if(propType == ptData)
+				else
 				{
-					int hint = m_cpVSAPI->mapGetDataTypeHint(cpProps,
+					const char * element = m_cpVSAPI->mapGetData(cpProps,
 						propKey, j, &error);
 					if(error)
 						elementString = "<error>";
-					else if(hint == dtUtf8)
-					{
-						const char * element = m_cpVSAPI->mapGetData(cpProps,
-							propKey, j, &error);
-						if(error)
-							elementString = "<error>";
-						else
-							elementString = QString::fromUtf8(element);
-					}
-					else if(hint == dtBinary)
+					else
 					{
+						elementString = QString::fromUtf8(element);
+						QByteArray elementAsUtf8 = elementString.toUtf8();
 						int len = m_cpVSAPI->mapGetDataSize(cpProps,
 							propKey, j, &error);
-						if(error)
-							elementString = "<error>";
-						else
-							elementString = QString("<binary with %1 bytes>")
-								.arg(len);
-					}
-					else
-					{
-						const char * element = m_cpVSAPI->mapGetData(cpProps,
-							propKey, j, &error);
-						if(error)
-							elementString = "<error>";
-						else
-						{
-							elementString = QString::fromUtf8(element);
-							QByteArray elementAsUtf8 = elementString.toUtf8();
-							int len = m_cpVSAPI->mapGetDataSize(cpProps,
-								propKey, j, &error);
-							if(elementAsUtf8.length() != len ||
-								elementAsUtf8.toStdString() != element)
-								elementString = "<unknown type>";
-						}
+						if(elementAsUtf8.length() != len ||
+							elementAsUtf8.toStdString() != element)
+							elementString = "<unknown type>";
 					}
 				}
 
@@ -982,13 +1172,7 @@ QString VapourSynthScriptProcessor::framePropsString(
 //		const VSFrame * a_cpFrame) const
 //==============================================================================
 
-void VapourSynthScriptProcessor::printFrameProps(const VSFrame * a_cpFrame)
+bool VapourSynthScriptProcessor::clearCoreCaches()
 {
-	QString message = tr("Frame properties:\n%1")
-		.arg(framePropsString(a_cpFrame));
-	emit signalWriteLogMessage(mtDebug, message);
+	return m_pVSScriptLibrary->clearCoreCaches(m_pCore);
 }
-
-// END OF void VapourSynthScriptProcessor::printFrameProps(
-//		const VSFrame * a_cpFrame)
-//==============================================================================
