@@ -70,6 +70,7 @@ MainWindow::MainWindow(SettingsManager *settings) : QMainWindow()
 	, m_lastSavedText()
 	, m_pJobServerWatcherSocket(nullptr)
 	, m_pGeometrySaveTimer(nullptr)
+	, m_pReloadTextTimer(nullptr)
 {
 	loadFonts();
 	vsedit::disableFontKerning(this);
@@ -114,8 +115,8 @@ MainWindow::MainWindow(SettingsManager *settings) : QMainWindow()
 		SIGNAL(signalWriteLogMessage(int, const QString &)),
 		this, SLOT(slotWriteLogMessage(int, const QString &)));
 
-	m_pVapourSynthPluginsManager =
-		new VapourSynthPluginsManager(m_pSettingsManager, this);
+	m_pVapourSynthPluginsManager = new VapourSynthPluginsManager(
+		m_pSettingsManager, m_pVSScriptLibrary->getVSAPI(), this);
 	VSPluginsList vsPluginsList = m_pVapourSynthPluginsManager->pluginsList();
 
 	m_ui.scriptEdit->setPluginsList(vsPluginsList);
@@ -148,6 +149,9 @@ MainWindow::MainWindow(SettingsManager *settings) : QMainWindow()
 	connect(m_pSettingsDialog, SIGNAL(signalSettingsChanged()),
 		m_pPreviewDialog, SLOT(slotSettingsChanged()));
 
+	connect(m_ui.scriptEdit, &QPlainTextEdit::textChanged,
+		m_pPreviewDialog, &PreviewDialog::slotScriptTextChanged);
+
 	m_pBenchmarkDialog =
 		new ScriptBenchmarkDialog(m_pSettingsManager, m_pVSScriptLibrary);
 	connect(m_pBenchmarkDialog,
@@ -184,6 +188,11 @@ MainWindow::MainWindow(SettingsManager *settings) : QMainWindow()
 	connect(m_pGeometrySaveTimer, &QTimer::timeout,
 		this, &MainWindow::slotSaveGeometry);
 
+	m_pReloadTextTimer = new QTimer(this);
+	m_pReloadTextTimer->setInterval(500);
+	connect(m_pReloadTextTimer, &QTimer::timeout,
+		this, &MainWindow::slotReloadTextFromDisk);
+
 	createActionsAndMenus();
 
 	slotChangeWindowTitle();
@@ -196,6 +205,9 @@ MainWindow::MainWindow(SettingsManager *settings) : QMainWindow()
 		showMaximized();
 
 	loadStartUpScript();
+
+	if(m_pSettingsManager->getReloadScriptFromDisk())
+		m_pReloadTextTimer->start();
 }
 
 // END OF MainWindow::MainWindow()
@@ -209,6 +221,9 @@ MainWindow::~MainWindow()
 		slotSaveGeometry();
 	}
 
+	if(m_pReloadTextTimer->isActive())
+		m_pReloadTextTimer->stop();
+
 	qInstallMessageHandler(0);
 	destroyOrphanQObjects();
 }
@@ -230,7 +245,16 @@ void MainWindow::slotWriteLogMessage(int a_messageType,
 void MainWindow::slotWriteLogMessage(const QString & a_message,
 	const QString & a_style)
 {
-	m_ui.logView->addEntry(a_message, a_style);
+	QString debugTypes[] = {
+		LOG_STYLE_DEBUG,
+		LOG_STYLE_QT_DEBUG,
+		LOG_STYLE_VS_DEBUG,
+	};
+	if(m_pSettingsManager->getShowDebugMessages() ||
+		!vsedit::contains(debugTypes, a_style))
+	{
+		m_ui.logView->addEntry(a_message, a_style);
+	}
 
 	QString fatalTypes[] = {LOG_STYLE_VS_FATAL, LOG_STYLE_QT_FATAL};
 	if(!vsedit::contains(fatalTypes, a_style))
@@ -441,9 +465,6 @@ void MainWindow::slotPreview()
 		return;
 	}
 
-	if(m_pSettingsManager->getReloadBeforeExecution())
-		reloadTexts();
-
 	m_pPreviewDialog->previewScript(m_ui.scriptEdit->text(), m_scriptFilePath);
 }
 
@@ -452,9 +473,6 @@ void MainWindow::slotPreview()
 
 void MainWindow::slotCheckScript()
 {
-	if(m_pSettingsManager->getReloadBeforeExecution())
-		reloadTexts();
-
 	VapourSynthScriptProcessor tempProcessor(m_pSettingsManager,
 		m_pVSScriptLibrary, this);
 
@@ -489,9 +507,6 @@ void MainWindow::slotBenchmark()
 		return;
 	}
 
-	if(m_pSettingsManager->getReloadBeforeExecution())
-		reloadTexts();
-
 	m_pBenchmarkDialog->initialize(m_ui.scriptEdit->text(), m_scriptFilePath);
 	m_pBenchmarkDialog->call();
 }
@@ -507,9 +522,6 @@ void MainWindow::slotEncode()
 		return;
 	}
 
-	if(m_pSettingsManager->getReloadBeforeExecution())
-		reloadTexts();
-
 	bool initialized = m_pEncodeDialog->initialize(
 		m_ui.scriptEdit->text(), m_scriptFilePath);
 	if(initialized)
@@ -524,9 +536,6 @@ void MainWindow::slotEnqueueEncodeJob()
 	if(m_scriptFilePath.isEmpty())
 		return;
 
-	if(m_pSettingsManager->getReloadBeforeExecution())
-		reloadTexts();
-
 	JobProperties properties;
 	properties.type = JobType::EncodeScriptCLI;
 	properties.scriptName = m_scriptFilePath;
@@ -561,6 +570,17 @@ void MainWindow::slotAbout()
 		aboutResource.size());
 	QString aboutString = QString::fromUtf8(aboutData);
 	aboutString.append(QString("\n\nBuilt with Qt %1").arg(QT_VERSION_STR));
+	QString VSAPIInfo = m_pVSScriptLibrary->VSAPIInfo();
+	if(VSAPIInfo.isEmpty())
+	{
+		aboutString.append(QString("\nVapourSynth not well configured."));
+	}
+	else
+	{
+		aboutString.append(QString("\nVapourSynth API Version: " + VSAPIInfo));
+		QString VSSAPIInfo = m_pVSScriptLibrary->VSSAPIInfo();
+		aboutString.append(QString("\nVSScript API Version: " + VSSAPIInfo));
+	}
 	QMessageBox msgBox(this);
 	msgBox.setText(aboutString);
 	msgBox.setWindowTitle("About VapourSynth Editor");
@@ -621,12 +641,17 @@ void MainWindow::slotSettingsChanged()
 		pAction->setShortcut(hotkey);
 	}
 
-	m_pVapourSynthPluginsManager->slotRefill();
+	m_pVapourSynthPluginsManager->slotRefill(m_pVSScriptLibrary->getVSAPI());
 	VSPluginsList vsPluginsList = m_pVapourSynthPluginsManager->pluginsList();
 	m_ui.scriptEdit->setPluginsList(vsPluginsList);
 	m_ui.scriptEdit->slotLoadSettings();
 	m_pTemplatesDialog->setPluginsList(vsPluginsList);
 	m_pTemplatesDialog->slotLoadSettings();
+
+	if(m_pSettingsManager->getReloadScriptFromDisk())
+		m_pReloadTextTimer->start(500);
+	else
+		m_pReloadTextTimer->stop();
 }
 
 // END OF void MainWindow::slotSettingsChanged()
@@ -647,6 +672,34 @@ void MainWindow::slotScriptFileDropped(const QString & a_filePath,
 //		bool * a_pHandled)
 //==============================================================================
 
+void MainWindow::slotReloadTextFromDisk()
+{
+	if(m_ui.scriptEdit->isModified())
+		return;
+
+	if(m_scriptFilePath.isEmpty())
+		return;
+
+	QFile scriptFile(m_scriptFilePath);
+	bool loadSuccess = scriptFile.open(QIODevice::ReadOnly | QIODevice::Text);
+	if(!loadSuccess)
+		return;
+
+	QByteArray utf8Script = scriptFile.readAll();
+	QString scriptText = QString::fromUtf8(utf8Script);
+	if(scriptText.isEmpty()) // To prevent an occasional bug?
+		return;
+	if(scriptText == m_ui.scriptEdit->text())
+		return;
+
+	QPoint pos = m_ui.scriptEdit->cursorPosition();
+	m_ui.scriptEdit->setPlainText(scriptText);
+	m_ui.scriptEdit->setCursorPosition(pos);
+	m_ui.scriptEdit->setModified(false);
+
+	m_pBenchmarkDialog->resetSavedRange();
+}
+
 void MainWindow::slotSaveGeometry()
 {
 	m_pGeometrySaveTimer->stop();
